@@ -1724,6 +1724,171 @@
 #define XPAR_XZDMA_15_ZDMA_CLK_FREQ_HZ 0
 
 
+/******************************************************************/
+
+/* Definitions for driver DPHY */
+#define XPAR_XDPHY_NUM_INSTANCES 1
+
+/* Definitions for peripheral MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY */
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_DEVICE_ID 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_BASEADDR 0x00010000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_HIGHADDR 0x0001FFFF
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_DPHY_MODE 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_EN_REG_IF 1
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_DPHY_LANES 2
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_ESC_CLK_PERIOD 50.000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_ESC_TIMEOUT 25600
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_HS_LINE_RATE 672
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_HS_TIMEOUT 65541
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_LPX_PERIOD 50
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_STABLE_CLK_PERIOD 5.000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_TXPLL_CLKIN_PERIOD 11.905
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_WAKEUP 1000000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_EN_TIMEOUT_REGS 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_HS_SETTLE_NS 149
+
+
+/******************************************************************/
+
+/* Canonical definitions for peripheral MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY */
+#define XPAR_DPHY_0_NUM_INSTANCES 0
+#define XPAR_DPHY_0_DEVICE_ID XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_PHY_DEVICE_ID
+#define XPAR_DPHY_0_BASEADDR 0x00010000
+#define XPAR_DPHY_0_HIGHADDR 0x0001FFFF
+#define XPAR_DPHY_0_DPHY_MODE 0
+#define XPAR_DPHY_0_EN_REG_IF 1
+#define XPAR_DPHY_0_DPHY_LANES 2
+#define XPAR_DPHY_0_ESC_CLK_PERIOD 50.000
+#define XPAR_DPHY_0_ESC_TIMEOUT 25600
+#define XPAR_DPHY_0_HS_LINE_RATE 672
+#define XPAR_DPHY_0_HS_TIMEOUT 65541
+#define XPAR_DPHY_0_LPX_PERIOD 50
+#define XPAR_DPHY_0_STABLE_CLK_PERIOD 5.000
+#define XPAR_DPHY_0_TXPLL_CLKIN_PERIOD 11.905
+#define XPAR_DPHY_0_WAKEUP 1000000
+#define XPAR_DPHY_0_EN_TIMEOUT_REGS 0
+#define XPAR_DPHY_0_HS_SETTLE_NS 149
+
+/* Definitions for driver MIPICSISS */
+#define XPAR_XCSISS_NUM_INSTANCES 1
+
+/* Definitions for peripheral MIPI_MIPI_CSI2_RX_SUBSYST_0 */
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_BASEADDR 0x80120000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_HIGHADDR 0x8013FFFF
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_DEVICE_ID 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CMN_INC_IIC 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CMN_NUM_LANES 2
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CMN_NUM_PIXELS 2
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CMN_PXL_FORMAT 0x2B
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CMN_VC 4
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CSI_BUF_DEPTH 4096
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CSI_EMB_NON_IMG 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_DPY_EN_REG_IF 1
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_DPY_LINE_RATE 672
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CSI_EN_CRC 1
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_CSI_EN_ACTIVELANES 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_EN_CSI_V2_0 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_EN_VCX 0
+
+
+/******************************************************************/
+
+/* Canonical definitions for peripheral MIPI_MIPI_CSI2_RX_SUBSYST_0 */
+#define XPAR_CSISS_0_BASEADDR 0x80120000
+#define XPAR_CSISS_0_HIGHADDR 0x8013FFFF
+#define XPAR_CSISS_0_DEVICE_ID XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_DEVICE_ID
+#define XPAR_CSISS_0_CMN_INC_IIC 0
+#define XPAR_CSISS_0_CMN_NUM_LANES 2
+#define XPAR_CSISS_0_CMN_NUM_PIXELS 2
+#define XPAR_CSISS_0_CMN_PXL_FORMAT 0x2B
+#define XPAR_CSISS_0_CMN_VC 16
+#define XPAR_CSISS_0_CSI_BUF_DEPTH 4096
+#define XPAR_CSISS_0_CSI_EMB_NON_IMG 0
+#define XPAR_CSISS_0_DPY_EN_REG_IF 1
+#define XPAR_CSISS_0_DPY_LINE_RATE 672
+#define XPAR_CSISS_0_CSI_EN_CRC 1
+#define XPAR_CSISS_0_CSI_EN_ACTIVELANES 0
+#define XPAR_CSISS_0_EN_CSI_V2_0 0
+#define XPAR_CSISS_0_EN_VCX 0
+
+
+/******************************************************************/
+
+/* Definitions for driver CSI */
+#define XPAR_XCSI_NUM_INSTANCES 1
+
+/* Definitions for peripheral MIPI_MIPI_CSI2_RX_SUBSYST_0_RX */
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_DEVICE_ID 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_BASEADDR 0x00000000
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_HIGHADDR 0x0000FFFF
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_CSI_LANES 2
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_CSI_OFFLOAD_NONIMAGE 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_CSI_EN_VC_SUPPORT 1
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_CSI_FIXED_VC 0
+#define XPAR_MIPI_MIPI_CSI2_RX_SUBSYST_0_RX_CSI_OPT3_FIXEDLANES 1
+
+
+/******************************************************************/
+
+/* Definitions for driver AXIVDMA */
+#define XPAR_XAXIVDMA_NUM_INSTANCES 2U
+
+/* Definitions for peripheral MIPI_AXI_VDMA_0 */
+#define XPAR_MIPI_AXI_VDMA_0_DEVICE_ID 0U
+#define XPAR_MIPI_AXI_VDMA_0_BASEADDR 0x80013000U
+#define XPAR_MIPI_AXI_VDMA_0_HIGHADDR 0x80013FFFU
+#define XPAR_MIPI_AXI_VDMA_0_NUM_FSTORES 4U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_MM2S 1U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_MM2S_DRE 1U
+#define XPAR_MIPI_AXI_VDMA_0_M_AXI_MM2S_DATA_WIDTH 128U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_S2MM 1U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_S2MM_DRE 1U
+#define XPAR_MIPI_AXI_VDMA_0_M_AXI_S2MM_DATA_WIDTH 128U
+#define XPAR_MIPI_AXI_VDMA_0_AXI_MM2S_ACLK_FREQ_HZ 0U
+#define XPAR_MIPI_AXI_VDMA_0_AXI_S2MM_ACLK_FREQ_HZ 0U
+#define XPAR_MIPI_AXI_VDMA_0_MM2S_GENLOCK_MODE 3U
+#define XPAR_MIPI_AXI_VDMA_0_MM2S_GENLOCK_NUM_MASTERS 1U
+#define XPAR_MIPI_AXI_VDMA_0_S2MM_GENLOCK_MODE 2U
+#define XPAR_MIPI_AXI_VDMA_0_S2MM_GENLOCK_NUM_MASTERS 1U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_SG 0U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_VIDPRMTR_READS 1U
+#define XPAR_MIPI_AXI_VDMA_0_USE_FSYNC 1U
+#define XPAR_MIPI_AXI_VDMA_0_FLUSH_ON_FSYNC 1U
+#define XPAR_MIPI_AXI_VDMA_0_MM2S_LINEBUFFER_DEPTH 4096U
+#define XPAR_MIPI_AXI_VDMA_0_S2MM_LINEBUFFER_DEPTH 4096U
+#define XPAR_MIPI_AXI_VDMA_0_INCLUDE_INTERNAL_GENLOCK 1U
+#define XPAR_MIPI_AXI_VDMA_0_S2MM_SOF_ENABLE 1U
+#define XPAR_MIPI_AXI_VDMA_0_M_AXIS_MM2S_TDATA_WIDTH 64U
+#define XPAR_MIPI_AXI_VDMA_0_S_AXIS_S2MM_TDATA_WIDTH 48U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_1 0U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_5 0U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_6 1U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_7 1U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_9 0U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_13 0U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_14 1U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_INFO_15 1U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_DEBUG_ALL 0U
+#define XPAR_MIPI_AXI_VDMA_0_ADDR_WIDTH 32U
+#define XPAR_MIPI_AXI_VDMA_0_ENABLE_VERT_FLIP 0U
+
+/* Definitions for peripheral MIPI_GPIO_IP_RESET */
+#define XPAR_MIPI_GPIO_IP_RESET_BASEADDR 0xA0013000
+#define XPAR_MIPI_GPIO_IP_RESET_HIGHADDR 0xA0013FFF
+#define XPAR_MIPI_GPIO_IP_RESET_DEVICE_ID 4
+#define XPAR_MIPI_GPIO_IP_RESET_INTERRUPT_PRESENT 0
+#define XPAR_MIPI_GPIO_IP_RESET_IS_DUAL 1
+
+/* Canonical definitions for peripheral MIPI_GPIO_IP_RESET */
+#define XPAR_GPIO_4_BASEADDR 0xA0013000
+#define XPAR_GPIO_4_HIGHADDR 0xA0013FFF
+#define XPAR_GPIO_4_DEVICE_ID XPAR_MIPI_GPIO_IP_RESET_DEVICE_ID
+#define XPAR_GPIO_4_INTERRUPT_PRESENT 0
+#define XPAR_GPIO_4_IS_DUAL 1
+
+#define XPAR_PSU_I2C_ZU_0_I2C_CLK_FREQ_HZ 100000000
+#define XPAR_PSU_I2C_ZU_1_I2C_CLK_FREQ_HZ 100000000
+
 /******************************************************************/
 
 #endif  /* end of protection macro */
