@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2016 Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (C) 2016 - 2020 Xilinx, Inc. All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
@@ -72,6 +50,9 @@
 *                           XV_HdmiTx_DdcRead APIs to prevent another DDC
 *                           transactions from happening in the middle of a DDC
 *                           transaction
+*       EB     16/07/19 Replaced sampling rate of 4 with 2 at the API
+*                           XV_HdmiTx_SetSampleRate
+* 2.50  EB     02/12/18 Added 3D Audio Support
 * </pre>
 *
 ******************************************************************************/
@@ -1083,6 +1064,7 @@ void XV_HdmiTx_SetPixelRate(XV_HdmiTx *InstancePtr)
 *
 * @param    InstancePtr is a pointer to the XV_HdmiTx core instance.
 * @param    SampleRate specifies the value that needs to be set.
+*       - 2 samples per clock
 *       - 3 samples per clock.
 *       - 5 samples per clock.
 *
@@ -1109,12 +1091,12 @@ void XV_HdmiTx_SetSampleRate(XV_HdmiTx *InstancePtr, u8 SampleRate)
 
     // Check for sample rate
     switch (SampleRate) {
-        case 3:
-            RegValue = 1;
+        case 2:
+            RegValue = 2;
             break;
 
-        case 4:
-            RegValue = 2;
+        case 3:
+            RegValue = 1;
             break;
 
         case 5:
@@ -1834,37 +1816,58 @@ int XV_HdmiTx_SetAudioChannels(XV_HdmiTx *InstancePtr, u8 Value)
     u32 Data;
     u32 Status;
     u8 AudioStatus;
+    u32 AudioCtrl;
 
-    AudioStatus = XV_HdmiTx_ReadReg((InstancePtr)->Config.BaseAddress,
-        		XV_HDMITX_AUD_CTRL_OFFSET) & XV_HDMITX_AUD_CTRL_RUN_MASK;
+    AudioCtrl = XV_HdmiTx_ReadReg((InstancePtr)->Config.BaseAddress,
+			XV_HDMITX_AUD_CTRL_OFFSET);
+
+    AudioStatus = AudioCtrl & XV_HDMITX_AUD_CTRL_RUN_MASK;
 
     // Stop peripheral
     XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
         (XV_HDMITX_AUD_CTRL_CLR_OFFSET), (XV_HDMITX_AUD_CTRL_RUN_MASK));
+    AudioCtrl &= ~((u32)XV_HDMITX_AUD_CTRL_RUN_MASK);
 
     switch (Value) {
+	// 32 Channels
+	case 32:
+            Data = 6;
+            Status = (XST_SUCCESS);
+            break;
+
+	// 24 Channels
+	case 24:
+            Data = 5;
+            Status = (XST_SUCCESS);
+            break;
+
+	// 12 Channels
+	case 12:
+            Data = 4;
+            Status = (XST_SUCCESS);
+            break;
 
         // 8 Channels
         case 8:
-            Data = 3 << XV_HDMITX_AUD_CTRL_CH_SHIFT;
+            Data = 3;
             Status = (XST_SUCCESS);
             break;
 
         // 6 Channels
         case 6:
-            Data = 2 << XV_HDMITX_AUD_CTRL_CH_SHIFT;
+            Data = 2;
             Status = (XST_SUCCESS);
             break;
 
         // 4 Channels
         case 4:
-            Data = 1 << XV_HDMITX_AUD_CTRL_CH_SHIFT;
+            Data = 1;
             Status = (XST_SUCCESS);
             break;
 
         // 2 Channels
         case 2:
-            Data = 0 << XV_HDMITX_AUD_CTRL_CH_SHIFT;
+            Data = 0;
             Status = (XST_SUCCESS);
             break;
 
@@ -1874,9 +1877,16 @@ int XV_HdmiTx_SetAudioChannels(XV_HdmiTx *InstancePtr, u8 Value)
     }
 
     if (Status == (XST_SUCCESS)) {
+	Data &= XV_HDMITX_AUD_CTRL_CH_MASK;
+        Data <<= XV_HDMITX_AUD_CTRL_CH_SHIFT;
+
+        AudioCtrl &= ~((u32)(XV_HDMITX_AUD_CTRL_CH_MASK <<
+			XV_HDMITX_AUD_CTRL_CH_SHIFT));
+        AudioCtrl |= Data;
+
         // Set active channels
         XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
-            (XV_HDMITX_AUD_CTRL_OFFSET), (Data));
+            (XV_HDMITX_AUD_CTRL_OFFSET), (AudioCtrl));
 
         // Store active channel in structure
         (InstancePtr)->Stream.Audio.Channels = Value;
@@ -1909,26 +1919,36 @@ int XV_HdmiTx_SetAudioChannels(XV_HdmiTx *InstancePtr, u8 Value)
 int XV_HdmiTx_SetAudioFormat(XV_HdmiTx *InstancePtr, XV_HdmiTx_AudioFormatType Value)
 {
     u32 Status;
+    u32 AudioCtrl;
+    u32 Data;
+
+    if (Value > XV_HDMITX_AUDFMT_3D) {
+	    return XST_FAILURE;
+    }
+
+    Data = Value;
 
     // Stop peripheral
     XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
         (XV_HDMITX_AUD_CTRL_CLR_OFFSET), (XV_HDMITX_AUD_CTRL_RUN_MASK));
 
-    // HBR audio
-    if (Value) {
-        XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
-            (XV_HDMITX_AUD_CTRL_SET_OFFSET), (XV_HDMITX_AUD_CTRL_AUDFMT_MASK));
-    }
+    AudioCtrl = XV_HdmiTx_ReadReg((InstancePtr)->Config.BaseAddress,
+		    XV_HDMITX_AUD_CTRL_OFFSET);
 
-    // L-PCM
-    else {
-        XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
-            (XV_HDMITX_AUD_CTRL_CLR_OFFSET), (XV_HDMITX_AUD_CTRL_AUDFMT_MASK));
-    }
+    Data &= XV_HDMITX_AUD_CTRL_AUDFMT_MASK;
+    Data <<= XV_HDMITX_AUD_CTRL_AUDFMT_SHIFT;
 
-	// Start peripheral
-	XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
-		(XV_HDMITX_AUD_CTRL_SET_OFFSET), (XV_HDMITX_AUD_CTRL_RUN_MASK));
+    AudioCtrl &= ~((u32)(XV_HDMITX_AUD_CTRL_AUDFMT_MASK <<
+			XV_HDMITX_AUD_CTRL_AUDFMT_SHIFT));
+    AudioCtrl |= Data;
+
+    XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
+                (XV_HDMITX_AUD_CTRL_OFFSET), (AudioCtrl));
+
+    // Start peripheral
+    XV_HdmiTx_WriteReg((InstancePtr)->Config.BaseAddress,
+		    (XV_HDMITX_AUD_CTRL_SET_OFFSET),
+		    (XV_HDMITX_AUD_CTRL_RUN_MASK));
 
     Status = (XST_SUCCESS);
 
@@ -1954,7 +1974,7 @@ XV_HdmiTx_AudioFormatType XV_HdmiTx_GetAudioFormat(XV_HdmiTx *InstancePtr)
     Xil_AssertNonvoid(InstancePtr != NULL);
 
     RegValue = XV_HdmiTx_ReadReg((InstancePtr)->Config.BaseAddress, (XV_HDMITX_AUD_CTRL_OFFSET));
-	RegValue = (RegValue & (XV_HDMITX_AUD_CTRL_AUDFMT_MASK)) >> XV_HDMITX_AUD_CTRL_AUDFMT_SHIFT;
+    RegValue = (RegValue >> XV_HDMITX_AUD_CTRL_AUDFMT_SHIFT) & (XV_HDMITX_AUD_CTRL_AUDFMT_MASK);
 
     return RegValue;
 }
