@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2016 Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (C) 2016 - 2020 Xilinx, Inc. All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
@@ -150,6 +128,7 @@
 * 2.2   EB     03/08/18 Marked XV_HdmiTx_AudioMute and XV_HdmiTx_AudioUnmute
 *                           as deprecated
 *       MMO    11/08/18 Added Bridge Overflow and Bridge Underflow (PIO IN)
+* 2.5   EB     02/12/18 Added 3D Audio Support
 * </pre>
 *
 ******************************************************************************/
@@ -208,7 +187,8 @@ typedef enum {
 */
 typedef enum {
     XV_HDMITX_AUDFMT_LPCM = 0,    // L-PCM
-    XV_HDMITX_AUDFMT_HBR          // HBR
+    XV_HDMITX_AUDFMT_HBR,         // HBR
+    XV_HDMITX_AUDFMT_3D           // 3D Audio
 } XV_HdmiTx_AudioFormatType;
 
 /**
@@ -1123,8 +1103,10 @@ int XV_HdmiTx_SelfTest(XV_HdmiTx *InstancePtr);
 
 /* Interrupt related functions in xv_hdmitx_intr.c */
 void XV_HdmiTx_IntrHandler(void *InstancePtr);
-int XV_HdmiTx_SetCallback(XV_HdmiTx *InstancePtr, u32 HandlerType,
-    void *CallbackFunc, void *CallbackRef);
+int XV_HdmiTx_SetCallback(XV_HdmiTx *InstancePtr,
+		XV_HdmiTx_HandlerType HandlerType,
+		void *CallbackFunc,
+		void *CallbackRef);
 
 
 /* Vendor Specific Information related functions in xv_hdmitx_vsif.c */
