@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2014 - 2017 Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (c) 2014 - 2020 Xilinx, Inc.  All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 * @file xil_mpu.c
@@ -104,7 +82,12 @@ static const struct {
 	{ 0x100000000, REGION_4G },
 };
 
+#if defined (__GNUC__)
+XMpu_Config Mpu_Config __attribute__((section(".boot")));
+#elif defined (__ICCARM__)
+#pragma default_function_attributes = @ ".boot"
 XMpu_Config Mpu_Config;
+#endif
 
 /************************** Function Prototypes ******************************/
 void Xil_InitializeExistingMPURegConfig(void);
@@ -581,36 +564,44 @@ u32 Xil_GetNextMPURegion(void)
 * @brief       Memory mapping for Cortex r5.
 *
 * @param       Physaddr is base physical address at which to start mapping.
+*                   NULL in Physaddr masks possible mapping errors.
 * @param       size of region to be mapped.
 * @param       flags used to set translation table.
 *
-* @return      Pointer to virtual address.
+* @return      Physaddr on success, NULL on error. Ambiguous if Physaddr==NULL
 *
-* @note:      Previously this was implemented in libmetal. Move
-*	      to embeddedsw as this functionality is specific to r5.
+* @note:    u32overflow() is defined for readability and (for __GNUC__) to
+*           - force the type of the check to be the same as the first argument
+*           - hide the otherwise unused third argument of the builtin
+*           - improve safety by choosing the explicit _uadd_ version.
+*           Consider __builtin_add_overflow_p() when available.
+*           Use an alternative (less optimal?) for compilers w/o the builtin.
 *
 ******************************************************************************/
-void* Xil_MemMap(UINTPTR Physaddr, size_t size, u32 flags)
+#ifdef __GNUC__
+#define u32overflow(a, b) ({typeof(a) s; __builtin_uadd_overflow(a, b, &s); })
+#else
+#define u32overflow(a, b) ((a) > ((a) + (b)))
+#endif /* __GNUC__ */
+void *Xil_MemMap(UINTPTR Physaddr, size_t size, u32 flags)
 {
 	size_t Regionsize = MPU_REGION_SIZE_MIN;
-	UINTPTR Basephysaddr = Physaddr & ~(Regionsize - 1);
+	UINTPTR Basephysaddr = 0, end = Physaddr + size;
 
 	if (!flags)
 		return (void *)Physaddr;
-
-	while(1) {
-		if (Regionsize < size) {
-			Regionsize <<= 1;
-			continue;
-		} else {
+	if (u32overflow(Physaddr, size))
+		return NULL;
+	for ( ; Regionsize != 0; Regionsize <<= 1) {
+		if (Regionsize >= size) {
 			Basephysaddr = Physaddr & ~(Regionsize - 1);
-			if ((Basephysaddr + Regionsize) < (Physaddr + size)) {
-				Regionsize <<= 1;
-				continue;
-			}
-			break;
+			if (u32overflow(Basephysaddr, Regionsize))
+				break;
+			if ((Basephysaddr + Regionsize) >= end)
+				return Xil_SetMPURegion(Basephysaddr,
+					Regionsize, flags) == XST_SUCCESS ?
+					(void *)Physaddr : NULL;
 		}
 	}
-	Xil_SetMPURegion(Basephysaddr, Regionsize, flags);
-	return (void *)Physaddr;
+	return NULL;
 }
