@@ -666,6 +666,7 @@
 #define XPAR_LCP_AR_INTC_HAS_FAST 0
 #define XPAR_LCP_AR_INTC_IVAR_RESET_VALUE 0x0000000000000010
 #define XPAR_LCP_AR_INTC_NUM_INTR_INPUTS 1
+#define XPAR_LCP_AR_INTC_NUM_SW_INTR 0
 #define XPAR_LCP_AR_INTC_ADDR_WIDTH 32
 
 
@@ -688,6 +689,7 @@
 #define XPAR_INTC_0_HAS_FAST 0U
 #define XPAR_INTC_0_IVAR_RESET_VALUE 0x0000000000000010U
 #define XPAR_INTC_0_NUM_INTR_INPUTS 1U
+#define XPAR_INTC_0_NUM_SW_INTR 0U
 #define XPAR_INTC_0_ADDR_WIDTH 32U
 #define XPAR_INTC_0_INTC_TYPE 0U
 
