@@ -30,7 +30,6 @@
 import collections
 import ctypes
 import itertools
-import os
 import re
 import struct
 import warnings
@@ -41,7 +40,6 @@ from .bitstream import Bitstream
 from .interrupt import Interrupt
 from .gpio import GPIO
 from .registers import RegisterMap
-from .registers import Register
 from .utils import ReprDict
 from .utils import _ExtensionsManager
 
@@ -53,7 +51,6 @@ __copyright__ = "Copyright 2016, Xilinx"
 __email__ = "pynq_support@xilinx.com"
 
 
-
 DRIVERS_GROUP = "pynq.lib"
 
 
@@ -107,7 +104,7 @@ def _assign_drivers(description, ignore_version, device):
 
 
 def _complete_description(ip_dict, hierarchy_dict, ignore_version,
-                          mem_dict, device):
+                          mem_dict, device, overlay):
     """Returns a complete hierarchical description of an overlay based
     on the three dictionaries parsed from HWH file.
 
@@ -120,6 +117,8 @@ def _complete_description(ip_dict, hierarchy_dict, ignore_version,
     starting_dict['memories'] = {re.sub('[^A-Za-z0-9_]', '', k): v
                                  for k, v in mem_dict.items() if v['used']}
     starting_dict['device'] = device
+    for k, v in starting_dict['hierarchies'].items():
+        v['overlay'] = overlay
     _assign_drivers(starting_dict, ignore_version, device)
     return starting_dict
 
@@ -348,7 +347,7 @@ class Overlay(Bitstream):
         self.ignore_version = ignore_version
         description = _complete_description(
             self.ip_dict, self.hierarchy_dict, self.ignore_version,
-            self.mem_dict, self.device)
+            self.mem_dict, self.device, self)
         self._ip_map = _IPMap(description)
 
         if download:
@@ -385,6 +384,8 @@ class Overlay(Bitstream):
     def free(self):
         if hasattr(self.device, 'free_bitstream'):
             self.device.free_bitstream()
+        if self.dtbo:
+            self.remove_dtbo()
 
     def download(self, dtbo=None):
         """The method to download a full bitstream onto PL.
@@ -449,16 +450,6 @@ class Overlay(Bitstream):
         """
         pr_block = self.__getattr__(partial_region)
         pr_block.download(bitfile_name=partial_bit, dtbo=dtbo)
-        pr_parser = pr_block.parsers[pr_block.pr_loaded]
-        pr_dtbo = pr_block.bitstreams[partial_bit].dtbo
-        self.device.update_partial_region(partial_region, pr_parser)
-        self._deepcopy_dict_from(self.device)
-        self.pr_dict[partial_region] = {'loaded': pr_block.pr_loaded,
-                                        'dtbo': pr_dtbo}
-        description = _complete_description(
-            self.ip_dict, self.hierarchy_dict, self.ignore_version,
-            self.mem_dict, self.device)
-        self._ip_map = _IPMap(description)
 
     def is_loaded(self):
         """This method checks whether a bitstream is loaded.
@@ -535,6 +526,7 @@ class Overlay(Bitstream):
         for ext in drivers_ext_man.list:
             importlib.import_module(ext.module_name)
 
+
 _ip_drivers = dict()
 _hierarchy_drivers = collections.deque()
 
@@ -703,7 +695,7 @@ class DefaultIP(metaclass=RegisterIP):
                 self._call_struct = struct.Struct(struct_string)
                 self._ctrl_reg = True
                 self.start_ert = self._start_ert
-                self.start_sw  = self._start_sw
+                self.start_sw = self._start_sw
                 self.call = self._call
                 if self.device.has_capability('ERT'):
                     self.start = self._start_ert
@@ -712,7 +704,8 @@ class DefaultIP(metaclass=RegisterIP):
         else:
             self._registers = None
         if 'index' in description:
-            self.cu_mask = 1 << description['adjusted_index']
+            cu_index = self.device.open_context(description)
+            self.cu_mask = 1 << cu_index
             self._setup_packet_prototype()
         if 'streams' in description:
             self.streams = {}
@@ -776,7 +769,7 @@ class DefaultIP(metaclass=RegisterIP):
         For details on the function's signature use the `signature` property.
         The type annotations provide the C types that the accelerator
         operates on. Any pointer types should be passed as `ContiguousArray`
-        objects created from the `pynq.allocate` class. Scalars should be 
+        objects created from the `pynq.allocate` class. Scalars should be
         passed as a compatible python type as used by the `struct` library.
 
         """
@@ -821,7 +814,7 @@ class DefaultIP(metaclass=RegisterIP):
         if kwargs:
             # Resolve any kwargs to make a single args tuple
             args = self._signature.bind(*args, **kwargs).args
-        args = [a.device_address if p else a for a, p in zip(args, 
+        args = [a.device_address if p else a for a, p in zip(args,
                                                              self._ptr_list)]
         arg_data = self._call_struct.pack(0, *args)
         bo = self.device.get_exec_bo()
@@ -861,7 +854,7 @@ class DefaultIP(metaclass=RegisterIP):
 
 
 class _IPMap:
-    """Class that stores drivers to IP, hierarches, interrupts and
+    """Class that stores drivers to IP, hierarchies, interrupts and
     gpio as attributes.
 
     """
@@ -1003,6 +996,7 @@ class DefaultHierarchy(_IPMap, metaclass=RegisterHierarchy):
         self.bitstreams = dict()
         self.pr_loaded = ''
         self.device = description['device']
+        self._overlay = description['overlay']
         super().__init__(description)
 
     @staticmethod
@@ -1017,7 +1011,7 @@ class DefaultHierarchy(_IPMap, metaclass=RegisterHierarchy):
         """
         return False
 
-    def download(self, bitfile_name, dtbo):
+    def download(self, bitfile_name, dtbo=None):
         """Function to download a partial bitstream for the hierarchy block.
 
         Since it is hard to know which hierarchy is to be reconfigured by only
@@ -1041,6 +1035,18 @@ class DefaultHierarchy(_IPMap, metaclass=RegisterHierarchy):
         if dtbo:
             self.bitstreams[bitfile_name].insert_dtbo()
 
+        self.device.update_partial_region(self.description['fullpath'],
+                                          self.parsers[self.pr_loaded])
+
+        self._overlay._deepcopy_dict_from(self.device)
+        self._overlay.pr_dict[self.description['fullpath']] = \
+            {'loaded': self.pr_loaded, 'dtbo': dtbo}
+        description = _complete_description(
+            self._overlay.ip_dict, self._overlay.hierarchy_dict,
+            self._overlay.ignore_version, self._overlay.mem_dict,
+            self._overlay.device, self._overlay)
+        self._overlay._ip_map = _IPMap(description)
+
     def _find_bitstream_by_abs(self, absolute_path):
         for i in self.bitstreams.keys():
             if self.bitstreams[i].bitfile_name == absolute_path:
